************* Notes ************* 
* This file must be in the same folder as all accompanying data files in order to run
* Within this folder, please create a "tables" subfolder, where all figures and tables will be deposited
* *Note* that the stock tickers for construction firms (sic=E01) have been anonymized **************

***first look at event study

clear all
set more off

drop _all
use "replication_file_stocks.dta",clear
ren stkcd code 
sort code
merge using effectivedate
drop if _m==2
drop _m

* we begin by consolidating data by date
egen totaldeath=sum(deathnumber),by(eventdate_state code)
egen accidents=count(deathnumber),by(eventdate_state code)
replace deathnumber=totaldeath

ren SIC sic1

egen fatality=count(death),by(sic1)

collapse ROA accidents fatality death CARs* effectivedate_stata totalassets PC* accidentyear , by(sic2 code eventdate_state province)
g year=accidentyear

* we count the number of accidents and deaths in the month that follows each accident
egen eventno=rank(eventdate_state),by(code)
tsset code eventno

g accident_month=accidents
g deathnumber_month=deathnumber
foreach g in 1 2 3 4 {
		replace accident_month=accident_month+f`g'.accidents if f`g'.eventdate_state-eventdate_state<31
		replace deathnumber_month=deathnumber_month+f`g'.deathnumber if f`g'.eventdate_state-eventdate_state<31
}

drop eventno

egen eventno=rank(eventdate_state),by(code)
tsset code eventno

* We iteratively get rid of "close" events to deal with overlap

foreach g in 31 {
gen gap4=eventdate_state-l4.eventdate_state<`g' & l4.eventdate_state~=.
tab sic if gap4==1
drop if gap4==1|f.gap4==1|f2.gap4==1|f3.gap4==1
drop gap4
gen gap3=eventdate_state-l3.eventdate_state<`g' & l3.eventdate_state~=.
tab sic if gap3==1
drop if gap3==1|f.gap3==1|f2.gap3==1
drop gap3
gen gap2=eventdate_state-l2.eventdate_state<`g' & l2.eventdate_state~=.
tab sic if gap2==1
drop if gap2==1|f.gap2==1
drop gap2
g gap1=eventdate_state-l.eventdate_state<`g' & l1.eventdate_state~=. 
tab sic if gap1==1
drop if gap1==1 
}

keep if CARs30~=.

gen la=log(totalassets)
gen ldeath=log( deathnumber)
gen ldeath_month=log(deathnumber_month)


keep if year>2007

* note that on average, there isn't much of a penalty
sum CARs3 CARs5 CARs10 CARs15 CARs30,d

//variable descriptions in the notes
local severe = "\emph{Severe} is an indicator variable denoting at least three fatalities from one accident in a firm-year observation"
local death_rate = "\emph{DeathRate} is equal to 1000*(\emph{Deaths/Employment})"
local safety_viol = "\emph{SafetyViol} is an indicator variable denoting whether a firm was reported in the media for safety violations"
local roa_f1 = "\emph{ROA\_F1} refers to ROA in year t+1"
local nsnp = `"\emph{NSNP} is a province-year variable denoting whether a province had passed a \enquote{no safety, no promotion} law in a previous year"'
local pollute = "\emph{Pollute} indicates firm-year observations where the firm was fined for environmental violations"
local connected_1 = "\emph{Connected} is a firm-year indicator variable, equal to one if a senior executive at the firm previously served as mayor or vice-mayor in the city (\enquote{Tingju Ji} in Chinese)"
local connected_2 = "where the firm is located or as a provincial or central government official of the same or higher rank"
local connected = "`connected_1' `connected_2'"
local connected_f1 = "\emph{Connected\_F1} denotes \emph{Connected} in year t+1"
local deaths = "\emph{Deaths} is firm-level worker fatalities per year"
local i_deaths = "\emph{I(Deaths$>$0)} is an indicator variable denoting at least one fatality in a firm-year observation"
local cap_int = "\emph{CapInt} is log value of the ratio of total assets to total employees"
local investment = "\emph{Investment} is the ratio of capital expenditure to total assets"
local state_ownership = "\emph{StateOwnership} is the ratio of state shares to total outstanding shares"
local var_connected = "Var(Ct'd)$>$0 denotes that we limit the sample to firms where there is variation in \emph{Connected} over the sample period 2008-2013, due either to the arrival or departure of a connected executive"
local monthly_deaths = "log(\emph{MonthlyDeaths}) is the log value of the total deaths that take place within a month of each initial accident"
local std_err = "Robust standard errors, clustered at the firm-level, are in parentheses"

//for referee tables
local return_volatility = "\emph{Return Volatility} is the standard deviation of daily stock returns in each year"
local leverage = "\emph{Leverage} is the ratio of total liabilities to total assets"


local significance = "* significant at 10\%; ** significant at 5\%; *** significant at 1\%"

local var_ctd = "Var(Ct'd)$>$0" 

label variable PC "Connected"
label variable ldeath_month "log(MonthlyDeaths)"
label variable la "log(Sales)"
label variable ROA "ROA"

****************************************************************
* TABLE 7
****************************************************************

xi: areg CARs3 PC  ldeath_month la ROA i.year i.sic2  , absorb(province) cluster(code)
eststo t7_3
foreach t in 5 10 15 20 25 30 {
	xi: areg CARs`t' PC  ldeath_month la ROA i.year i.sic2  , absorb(province) cluster(code)
	eststo t7_`t'
}

esttab t7_3 t7_5 t7_10 t7_15 t7_20 t7_25 t7_30   ///
using ./tables/t7.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps   ///
nodepvars b(%9.3f) legend noabbrev style(tex) constant   ///
title("Table 7: The impact of political connections on cumulative abnormal event returns (CARs): OLS regression")   ///
mtitles(CARs[1,3] CARs[1,5] CARs[1,10] CARs[1,15] CARs[1,20] CARs[1,25] CARs[1,30])   ///
label stats(N r2_a, fmt(%9.0g %9.3g) labels("Observations" "Adjusted R-Squared")) se  ///
order(PC ldeath_month la ROA _cons)    ///
keep(PC ldeath_month la ROA _cons)     ///
prefoot("\hline" ///
		"Fixed Effects & \multicolumn{7}{c}{Province, Industry \& Year}\\" ///
		"\hline")  ///
nonotes ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			"\caption{Notes: A standard OLS model is used to estimate the impact of political connections on CARs.  CARs[1,K] is the cumulative abnormal event return, estimated using a standard Fama-French-Carhart four-factor model, over the window of [1,K] where the accident day is set as 1; `connected_1' `connected_2'; `monthly_deaths'.  `std_err'.  \newline `significance'.}"  ///
			"\end{table}")  ///
substitute(	\begin{table}[htbp]\centering \begin{table}[htbp]\centering\footnotesize{ )


* now some graphs
save temp,replace
use temp,clear
g x=2
drop if PC==.
collapse CARs*,by(x)
reshape long CARs, i(x) j(window)
keep if window<31
reshape wide CARs, i(window) j(x)
ren CARs2 CARs_all
sort window
//browse

//eric 09/15/2014
//save this to be merged onto CARs0 and CARs1
save cars_all.dta, replace

use temp,clear
collapse CARs*,by(PC)
reshape long CARs, i(PC) j(window)
keep if window<31
drop if PC==.
reshape wide CARs, i(window) j(PC)

**************************************
* Figure 3
**************************************
merge 1:1 window using cars_all.dta

label variable CARs0 "Unconnected Firms"
label variable CARs1 "Connected Firms"
label variable CARs_all "All Firms"

twoway	(line CARs0 window, lcolor(blue) lpattern(dash))  ///
		(line CARs1 window, lcolor(red) lpattern(dash_dot))  ///
		(line CARs_all window, lcolor(green) lpattern(solid)),  ///
		ytitle("Cumulative Abnormal Returns") xtitle("Days Since Accident")  ///
		legend(rows(3))  ///
		graphregion(fcolor(white) lcolor(white) color(white)) legend(region(lcolor(white)))
graph export tables/cars.png, replace


file open f3 using "tables/f3.tex", write replace
file write f3 "\begin{figure}[H]" _n
file write f3 "\begin{center}" _n
file write f3 "Figure 3: Market reaction to fatal accidents, Connected versus Unconnected firms\\" _n
file write f3 "\includegraphics[scale=\fullscale]{cars.png}" _n
file write f3 "\end{center}" _n
file write f3 "\caption{Notes: Each data point represents the post-accident cumulative abnormal returns CARs[1,K], estimated using a standard Fama-French four-factor model, over the window of [1,K] where the accident date is set as 1.  `connected_1' `connected_2'. }" _n
file write f3 "\end{figure}" _n
file close f3

drop _all
**************************************************************************************************************
***********now look at firm-year accident panel data
**************************************************************************************************************

use "replication_file_panel.dta",clear
drop if PC==.
drop if employee==.

g operatingrevenue=sales
* ren operaingrevenue operatingrevenue
g ls=log(sales)

replace meansafety=.02*(operatingcost/operatingrev) if sic2=="E01"

**Again, all right hand variables are in year t, while ldeath is in year t+1
**that means, if year==2007, the death toll number is for 2008, while the PC and financials are for (year-end) 2007.

gen la=log(totalassets)
gen ldeath=log(1+ death)
gen d_death=death>0 if death~=.

g log_employee =log(employee)
g deathrate=1000*death/employee

g capint=la -log_employee
save full_data,replace

*****************************************************************************
* Figure 1 
*****************************************************************************

gen death_hist = death
replace death_hist = 15 if death_hist > 15
label variable death_hist "Deaths"

hist 	death_hist if death_hist > 0, width(1) discrete color(blue) ///
		title("")  ///
		xlabel(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15) ytitle("Fraction of Observations")  ///
		graphregion(fcolor(white) lcolor(white) color(white)) legend(region(lcolor(white)))
graph export tables/death_pct.png, replace


/*
hist 	death_hist if death_hist > 0, width(1) discrete freq color(blue) ///
		xlabel(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15) ytitle("Number of Observations")  ///
		graphregion(fcolor(white) lcolor(white) color(white)) legend(region(lcolor(white)))
graph export tables/death_freq.png, replace
*/

file open f1 using "tables/f1.tex", write replace
file write f1 "\begin{figure}[H]" _n
file write f1 "\begin{center}" _n
file write f1 "Figure 1: Frequency distribution of \emph{Deaths}\\" _n
file write f1 "\includegraphics[scale=\fullscale]{death_pct.png}" _n
file write f1 "\end{center}" _n
file write f1 "\caption{Notes: The sample used to construct this figure includes the 226 firm-year observations in which \emph{Deaths} is positive.  `deaths'.  In this figure, the distribution of \emph{Deaths} is censored at a maximum of 15.  }" _n
file write f1 "\end{figure}" _n
file close f1

use full_data,replace

* summary stats for Table 1
drop if year<2007

egen temp=mean(PC),by(code)
g var_PC=temp~=0 & temp~=1 if temp~=.
drop temp
* deathrate has some really long tails so we winsorize
egen deathrate_99=pctile(deathrate),p(95)
replace deathrate=deathrate_99 if deathrate>deathrate_99
g pollute=sign(pollutionticket) 

* drop if zero sales in at least one year
egen mins=min(sales),by(code)
drop if mins==0

save data_post2007,replace

* TABLE 1
sum ldeath d_death deathrate severetag PC post sp ls capint ROA_w log_employee iv viol pollute meansafety,


//to prep, label variables as labeled in Table 1A
label variable ldeath "log(1+Deaths)"
label variable d_death "I(Deaths$>$0)"
label variable deathrate "DeathRate"
label variable severetag "Severe"
label variable PC "Connected"
label variable post "NSNP"
label variable sp "State Ownership"
label variable ls "log(Sales)"
label variable capint "CapInt"
label variable ROA_w "ROA"
label variable log_employee "log(Employment)"
label variable iv "Investment"
label variable viol "SafetyViol"
label variable pollute "Pollute"

//Table 1A out to latex
file open t1a using "tables/t1a.tex", write replace
file write t1a "\begin{table}[htbp]\centering\footnotesize{" _n
file write t1a "\caption{Table 1A: Summary Statistics for firm-year panel data}" _n
file write t1a "\begin{tabular}{l*{6}{c}}" _n
file write t1a "\hline\hline" _n
file write t1a "Variable & Mean & SD & Median & Min & Max & Obs \\" _n
file write t1a "\hline" _n

foreach var of varlist ldeath d_death deathrate severetag PC post sp ls capint ROA_w log_employee iv viol pollute {
	sum `var', d
	file write t1a "`:var label `var'' & " %9.3f (r(mean)) " & " %9.3f (r(sd)) " & " %9.3f (r(p50)) " & " %9.3f (r(min)) " & " %9.3f (r(max)) " & " %9.0f (r(N)) "\\" _n 
}

file write t1a "\hline\hline" _n
file write t1a "\end{tabular}}" _n
file write t1a "\caption{Notes: All variables are at the firm-year level, and includes our full sample of 1475 firms. `deaths'; `i_deaths'; `death_rate'; `severe'; `connected_1' `connected_2'; `state_ownership'; `cap_int'; `nsnp'; `safety_viol'; `pollute'.}" _n
file write t1a "\end{table}" _n
file close t1a



//Table 1B

bys PC: sum ldeath d_death deathrate severetag post sp ls capint ROA_w log_employee iv viol pollute meansafety,
* generate p-values
foreach v in ldeath d_death deathrate severetag post sp ls capint ROA_w log_employee iv viol pollute meansafety {
	pwmean `v',over(PC)
}

file open t1b using "tables/t1b.tex", write replace
file write t1b "\begin{table}[htbp]\centering\footnotesize{" _n
file write t1b "\caption{Table 1B: Summary Statistics for firm-year panel data: politically connected vs. politically unconnected}" _n
file write t1b "\begin{tabular}{l c c l c}" _n  //{l*{4}{c}}
file write t1b "\hline\hline" _n
file write t1b "Variable & PoliticallyConnected=0 & PoliticallyConnected=1 & Difference & (Std Error) \\" _n
file write t1b "\hline" _n

foreach var of varlist ldeath d_death deathrate severetag post sp ls capint ROA_w log_employee iv viol pollute {
	sum `var' if PC == 0
	local mean_pc0 = r(mean)
	sum `var' if PC == 1
	local mean_pc1 = r(mean)
	//look at the "saved results" section of "help pwmean" to find the matrices where results are stored
	pwmean `var', over(PC)
	mat ebvs = e(b_vs)
	mat evvs = e(V_vs)
	
	local stderr = sqrt(evvs[1,1])
	
	//significance of difference
	ttest `var', by(PC)
	local pval = r(p)
	local sig = ""
	if `pval' < .1 {
		local sig = "*"
	}
	if `pval' < .05 {
		local sig = "**"
	}
	if `pval' < .01 {
		local sig = "***"
	}
	
	file write t1b "`:var label `var'' & " %9.3f (`mean_pc0') " & " %9.3f (`mean_pc1') " & " %9.3f (ebvs[1,1]) "`sig' & (" %7.3f (`stderr') ")\\" _n 
}

file write t1b "\hline\hline" _n
file write t1b "\end{tabular}}" _n
file write t1b "\caption{Notes: All variables are at the firm-year level, and includes our full sample of 1475 firms. `deaths'; `i_deaths'; `death_rate'; `severe'; `connected_1' `connected_2'; `state_ownership'; `cap_int'; `nsnp'; `safety_viol'; `pollute'.  \newline `significance'.}" _n
file write t1b "\end{table}" _n
file close t1b



//Table 1C

sum ldeath d_death deathrate severetag post sp ls capint ROA_w log_employee iv viol pollute meansafety,
preserve
drop if var_PC==0
foreach v in ldeath d_death deathrate severetag post sp ls capint ROA_w log_employee iv viol pollute meansafety {
	pwmean `v' ,over(PC)
}

file open t1c using "tables/t1c.tex", write replace
file write t1c "\begin{table}[htbp]\centering\footnotesize{" _n
file write t1c "\caption{Table 1C: Firm-year panel data: politically connected vs. politically unconnected firms, Var(Connected)$>$0 sample}" _n
file write t1c "\begin{tabular}{l c c l c}" _n
file write t1c "\hline\hline" _n
file write t1c "Variable & PoliticallyConnected=0 & PoliticallyConnected=1 & Difference & (Std Error) \\" _n
file write t1c "\hline" _n

foreach var of varlist ldeath d_death deathrate severetag post sp ls capint ROA_w log_employee iv viol pollute {
	sum `var' if PC == 0 & var_PC == 1
	local mean_pc0 = r(mean)
	sum `var' if PC == 1 & var_PC == 1
	local mean_pc1 = r(mean)
	//look at the "saved results" section of "help pwmean" to find the matrices where results are stored
	pwmean `var', over(PC)
	mat ebvs = e(b_vs)
	mat evvs = e(V_vs)
	
	local stderr = sqrt(evvs[1,1])
	
	//significance of difference
	ttest `var', by(PC)
	local pval = r(p)
	local sig = ""
	if `pval' < .1 {
		local sig = "*"
	}
	if `pval' < .05 {
		local sig = "**"
	}
	if `pval' < .01 {
		local sig = "***"
	}
	
	file write t1c "`:var label `var'' & " %9.3f (`mean_pc0') " & " %9.3f (`mean_pc1') " & " %9.3f (ebvs[1,1]) "`sig' & (" %7.3f (`stderr') ")\\" _n 
}

file write t1c "\hline\hline" _n
file write t1c "\end{tabular}}" _n
file write t1c "\caption{Notes: All variables are at the firm-year level, and includes the sample of firms where there is variation in \emph{Connected} during our sample period (the Var(Connected)$>$0 sample), a total of 325 observations. `deaths'; `i_deaths'; `death_rate'; `severe'; `connected_1' `connected_2'; `state_ownership'; `cap_int'; `nsnp'; `safety_viol'; `pollute'.  \newline `significance'.}" _n
file write t1c "\end{table}" _n
file close t1c

restore

bys PC: sum ldeath d_death deathrate severetag PC post sp ls capint ROA_w log_employee iv viol pollute meansafety if var_PC==1,


g industrygroup=sic1
replace industrygroup=sic2 if sic2=="B01" 
tab industrygroup PC,sum(d_death)

egen obs=sum(d_death~=.),by(sic2) 
tab sic2 PC if obs>100 ,sum(deathrate)

tab sic2 PC if obs>100 & var_PC==1,sum(deathrate)
tab PC if obs<100,sum(deathrate)

//Figure 2A and 2B prep
gen sic2_bargraph = sic2
replace sic2_bargraph = "Coal Mining" if sic2 == "B01"
replace sic2_bargraph = "Chemicals" if sic2 == "C43"
replace sic2_bargraph = "Smelting Ferrous Metals" if sic2 == "C65"
replace sic2_bargraph = "Smelting Nonferrous Materials" if sic2 == "C67"
replace sic2_bargraph = "Construction" if sic2 == "E01"
replace sic2_bargraph = "Other" if inlist(sic2, "B03", "B05", "B07" "C41")
replace sic2_bargraph = "Other" if sic2_bargraph == "C41"

gen bar_order = .
replace bar_order = 1 if sic2_bargraph == "Coal Mining"
replace bar_order = 2 if sic2_bargraph == "Chemicals"
replace bar_order = 3 if sic2_bargraph == "Smelting Ferrous Metals"
replace bar_order = 4 if sic2_bargraph == "Smelting Nonferrous Materials"
replace bar_order = 5 if sic2_bargraph == "Construction"
replace bar_order = 6 if sic2_bargraph == "Other"

****************************************************
* Figure 2A 
****************************************************
gen deathrate_c = deathrate if PC == 1 & obs > 100
replace deathrate_c = deathrate if PC == 1 & obs < 100 & sic2_bargraph == "Other"
gen deathrate_nc = deathrate if PC == 0 & obs > 100
replace deathrate_nc = deathrate if PC == 0 & obs < 100 & sic2_bargraph == "Other"

graph 	bar deathrate_nc deathrate_c, over(sic2_bargraph, label(angle(45)) sort(bar_order))  ///
		bar(1, blwidth(thin) fcolor(none) lcolor(black)) bar(2, color(blue))  ///
		legend(order(1 "Unconnected" 2 "Connected")) ytitle("Deaths per 1000 Employees") ///
		graphregion(fcolor(white) lcolor(white) color(white)) legend(region(lcolor(white)))
graph export tables/deathrate_sic_fullsample.png, replace

****************************************************
* Figure 2B 
****************************************************
gen deathrate_c_varpc = deathrate if PC == 1 & var_PC == 1 & obs > 100
replace deathrate_c_varpc = deathrate if obs < 100 & var_PC == 1 & sic2_bargraph == "Other"
gen deathrate_nc_varpc = deathrate if PC == 0 & var_PC == 1 & obs > 100
replace deathrate_nc_varpc = deathrate if obs < 100 & var_PC == 0 & sic2_bargraph == "Other"

graph 	bar deathrate_nc_varpc deathrate_c_varpc, over(sic2_bargraph, label(angle(45)) sort(bar_order))  ///
		bar(1, blwidth(thin) fcolor(none) lcolor(black) lpattern(solid)) bar(2, color(blue))  ///
		legend(order(1 "Unconnected" 2 "Connected")) ytitle("Deaths per 1000 Employees") ///
		graphregion(fcolor(white) lcolor(white) color(white)) legend(region(lcolor(white)))
graph export tables/deathrate_sic_varpc.png, replace



file open f2a using "tables/f2a.tex", write replace
file write f2a "\begin{figure}[H]" _n
file write f2a "\begin{center}" _n
file write f2a "Figure 2A: Average \emph{DeathRate} at Connected versus Unconnected Firms, by Industry (full sample)\\" _n
file write f2a "\includegraphics[scale=\fullscale]{deathrate_sic_fullsample.png}" _n
file write f2a "\end{center}" _n
file write f2a "\caption{Notes: The figure is contructed using the full sample of 1475 firm-year observations.  `death_rate'.}" _n
file write f2a "\end{figure}" _n
file close f2a

file open f2b using "tables/f2b.tex", write replace
file write f2b "\begin{figure}[H]" _n
file write f2b "\begin{center}" _n
file write f2b "Figure 2B: Average \emph{DeathRate} at Connected versus Unconnected Firms, by Industry (Var(Connected)$>$0 sample)\\" _n
file write f2b "\includegraphics[scale=\fullscale]{deathrate_sic_varpc.png}" _n
file write f2b "\end{center}" _n
file write f2b "\caption{Notes: The figure is contructed using the Var(Connected)$>$0 sample of 325 firm-year observations. `var_connected'. `death_rate'.}" _n
file write f2b "\end{figure}" _n
file close f2b


//figures end here
//stop


* NOW REGRESSION TABLES

*****************************************************************
* TABLE 2
*****************************************************************
label variable death " "
label variable PC "Connected"
label variable ls "log(Sales)"
label variable ROA_w "ROA"
label variable capint "CapInt"
label variable sp "StateOwnership"
label variable iv "Investment"


egen ind=group(sic2)
* we begin with negative binomial specifications (poisson fails goodness of fit test - it's just not the right shape)
xi: nbreg death PC , //cluster(code) //irr
eststo t2_1
//outreg2 PC ls ROA_w iv capint sp  using Table2.xls, replace sortvar(PC ls ROA_w capint sp  iv) addtext(Fixed Effects, "-", Sample, "Full") 
xi: nbreg death PC ls ROA_w capint sp  iv , //cluster(code) //irr
eststo t2_2
//outreg2 PC ls ROA_w iv capint sp  using Table2.xls, append sortvar(PC ls ROA_w capint sp  iv) addtext(Fixed Effects, "-", Sample, "Full") 
xi: nbreg death PC ls ROA_w capint sp  iv i.ind i.year i.province, //cluster(code) //irr
eststo t2_3
//outreg2 PC ls ROA_w iv capint sp  using Table2.xls, append sortvar(PC ls ROA_w capint sp  iv) addtext(Fixed Effects, "Year;Industry;Province", Sample, "Full") 
xi: xtnbreg death PC ls ROA_w capint sp  iv i.year , i(code) fe
eststo t2_4
//outreg2 PC ls ROA_w iv capint sp  using Table2.xls, append sortvar(PC ls ROA_w capint sp  iv) addtext(Fixed Effects, "Year;Firm", Sample, "Full") 
xi: nbreg death PC ls ROA_w capint sp  iv i.ind i.year i.province if var_PC==1, //cluster(code) //irr
eststo t2_5
//outreg2 PC ls ROA_w iv capint sp  using Table2.xls, append sortvar(PC ls ROA_w capint sp  iv) addtext(Fixed Effects, "Year;Industry;Province", Sample, "Var(Connected)>0") 
xi: xtnbreg death PC ls ROA_w capint sp  iv i.year if var_PC==1, i(code) fe
eststo t2_6
//outreg2 PC ls ROA_w iv capint sp  using Table2.xls, append sortvar(PC ls ROA_w capint sp  iv) addtext(Fixed Effects, "Year;Firm", Sample, "Var(Connected)>0") 


esttab t2_1 t2_2 t2_3 t2_4 t2_5 t2_6  ///
using ./tables/t2.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps   ///
nodepvars b(%9.3f) legend constant noabbrev style(tex)  ///
title("Table 2: The impact of political connections on workplace deaths: negative binomial regression")   ///
nomtitles ///
label stats(N ll, fmt(%9.0g %9.3g) ///
labels("Observations" "Log pseudolikelihood")) se  ///
order(PC ls ROA_w capint sp iv _cons)    ///
keep(PC ls ROA_w capint sp iv _cons)     ///
nonotes ///
posthead(	" & \multicolumn{6}{c}{Columns 1 - 6: Deaths} \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"Fixed Effects & - & - & Year; Industry; Province & Firm; Year & Year; Industry; Province & Firm; Year\\" ///
		"Sample & Full & Full & Full & Full & `var_ctd' & `var_ctd' \\" ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			"\caption{Notes: All variables are at the firm-year level.  `deaths'; `connected_1' `connected_2'; `cap_int'; `investment'; `state_ownership'. `var_connected'.  Robust standard errors are in parentheses; with the exception of columns 4 and 6 standard errors are clustered at the firm-level. \newline `significance'.}"  ///			
			"\end{table}")  ///
substitute(	\begin{table}[htbp]\centering \begin{table}[htbp]\centering\footnotesize{ "lnalpha" "ln($\alpha$)" )

* TABLE 3 
* now std ols
//xi: areg ldeath PC ls ROA_w iv capint sp i.year i.sic2, absorb(province) cluster(code) 
//outreg2 PC ls ROA_w iv capint sp  using Table3.xls, replace sortvar(PC ls ROA capint sp  iv) addtext(Fixed Effects, "DROP THIS COLUMN") 
foreach var in ldeath deathrate d_death {
xi: areg `var' PC ls ROA_w iv capint sp  i.year i.sic2, absorb(province) cluster(code) 
eststo t3_`var'_1
//outreg2 PC ls ROA_w iv capint sp  using Table3.xls, append sortvar(PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Industry;Province",Sample, "Full") 
xi: areg `var' PC ls ROA_w iv capint sp log_emp i.year i.sic2 if var_PC==1, absorb(province) cluster(code) 
eststo t3_`var'_2
//outreg2 PC ls ROA_w iv capint sp  using Table3.xls, append sortvar(PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Industry;Province",Sample, "Var(Connected)>0") 
xi: areg `var' PC ls ROA_w iv capint sp  i.year  if var_PC==1, absorb(code) cluster(code) 
eststo t3_`var'_3
//outreg2 PC ls ROA_w iv capint sp  using Table3.xls, append sortvar(PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Firm",Sample, "Var(Connected)>0") 
}


esttab t3_ldeath_1 t3_ldeath_2 t3_ldeath_3   t3_deathrate_1 t3_deathrate_2 t3_deathrate_3   t3_d_death_1 t3_d_death_2 t3_d_death_3    ///
using ./tables/t3.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps  ///
nodepvars b(%9.3f) legend constant noabbrev style(tex)  ///
title("Table 3: The impact of political connections on workplace deaths: OLS regression")   ///
nomtitles ///
label stats(N r2, fmt(%9.0g %9.3g)       ///
labels("Observations" "R-Squared")) se  ///
order(PC ls ROA_w capint sp iv _cons)    ///
keep(PC ls ROA_w capint sp iv _cons)     ///
nonotes ///
posthead(	" & \multicolumn{3}{c}{Columns 1 - 3: log(1 + death)} & \multicolumn{3}{c}{Columns 4 - 6: DeathRate} & \multicolumn{3}{c}{Columns 7 - 9: I(Deaths$ >$ 0)} \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"              & Year; Industry; & Year; Industry; & Year; Firm & Year; Industry; & Year; Industry; & Year; Firm & Year; Industry; & Year; Industry; & Year; Firm  \\"  ///
		"Fixed Effects & Province        & Province        &            & Province        & Province        &            & Province        & Province        &             \\"  ///
		"Sample        & Full & `var_ctd' & `var_ctd' & Full & `var_ctd' & `var_ctd' & Full & `var_ctd' 0 & `var_ctd' \\"  ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			"\caption{Notes: All variables are at the firm-year level.  `deaths'; `i_deaths'; `death_rate'; `connected_1' `connected_2'; `cap_int'; `investment'; `state_ownership'. `var_connected'. `std_err'. \newline `significance'.}"  ///
			"\end{sidewaystable}")  ///
substitute(	\begin{table}[htbp]\centering \begin{sidewaystable}[htbp]\centering\scriptsize{ )


* TABLE A2 (TABLE A1 IS IN A SEPARATE FILE)

***Propensity Score Matching
***code source: Becker Sascha and Andrea Ichino (2002), Estimation of average treatment effects based on propensity scoresThe Stata Journal, Vol 2, Number 4, pp. 358C377

//downloaded pscore version 2.02 from here: http://sobecker.userweb.mwn.de/pscore.html

clear all
set more off

use data_post2007.dta, clear
gen sic0=substr(sic2,1,1)
xi: reg  deathrate  PC la ROA_w iv log_employee i.year i.sic0 i.province
save temp, replace
xi:pscore PC sp ls capint  ROA_w iv log_employee  i.sic0 , pscore(mypscore) blockid(myblock) comsup numblo(8) level(0.01) logit

**method 1: Nearest-Neighbor Matching
xi:attnw  deathrate PC sp ls capint ROA_w iv log_employee    i.sic0 i.year  i.province,  comsup boot reps(50) logit

//number of treatment and control observations
local attnw_nt = r(ntnw)
local attnw_nc = r(ncnw)

//treatment effect, std. err., and t-stat
local attnw_t = r(attnw)
local attnw_se = r(seattnw)
local attnw_tstat = r(tsattnw)
/*
local attnw_t = `: di %9.3 r(attnw)'
local attnw_se = `: di %9.3 r(seattnw)'
local attnw_tstat = `: di %9.3 r(tsattnw)'
*/


///*
**method 2: Kernel Matching
xi:attk deathrate PC sp ls capint ROA_w iv log_employee  i.sic0 i.year i.province , pscore( mypscore)  comsup bootstrap reps(100) dots logit epan bwidth(0.04)

//number of treatment and control observations
local attk_nt = r(ntk)
local attk_nc = r(nck)

//treatment effect, std. err., and t-stat
local attk_t = r(attk)
local attk_bse = r(bseattk)  //bootstrapped std err
local attk_btstat = r(btsattk)  //bootstrapped t-stat


**method 3: Radius Matching
xi:attr deathrate PC sp ls capint ROA_w iv log_employee   i.sic0 i.year i.province, pscore(mypscore) comsup bootstrap reps(100) logit radius(0.1)

//number of treatment and control observations
local attr_nt = r(ntr)
local attr_nc = r(ncr)

//treatment effect, std. err., and t-stat
local attr_t = r(attr)
local attr_se = r(seattr)
local attr_bse = r(bseattr)
local attr_tstat = r(tsattr)
//*/

//table A2 to latex

local notes_ta2_1 = "Stata codes come from Sascha Becker and Andrea Ichino (2002).  ATT stands for \enquote{Average Treatment Effect on the Treated}."
local notes_ta2_2 = "Bootstrap replication number is set at 100 in each case.  A logit model is used in the propensity score test, where firms are matched on these dimensions: log(Sales), ROA, log(Employment), Investment and SIC-1 digit industry."
local notes_ta2_3 = "The Epanechinikov kernel is used in the kernel matching where the bandwidth is set at 0.04, smaller than the default value of 0.06."

file open ta2 using "tables/ta2.tex", write replace
file write ta2 "\begin{table}[htbp]\centering\footnotesize{" _n
file write ta2 "\caption{Appendix Table A2: Propensity Score Tests}" _n
file write ta2 "\begin{tabular}{l*{5}{c}}" _n
file write ta2 "\hline\hline" _n
file write ta2 "Dependent Variable & Matching Method & Number of Treatment Firms & Number of Control Firms & ATT & Std. Err. \\" _n
file write ta2 "\hline" _n
file write ta2 "DeathRate & Nearest-Neighbor Matching & `attnw_nt' & `attnw_nc' & " %9.3f (`attnw_t') " & " %9.3f (`attnw_se') " \\" _n
file write ta2 "DeathRate & Kernel Matching           & `attk_nt'  & `attk_nc'  & " %9.3f (`attk_t') " & " %9.3f (`attk_bse') " \\" _n
file write ta2 "DeathRate & Radius Matching           & `attr_nt'  & `attr_nc'  & " %9.3f (`attr_t') " & " %9.3f (`attr_bse') " \\" _n


file write ta2 "\hline\hline" _n
file write ta2 "\end{tabular}}" _n
file write ta2 "\caption{Notes: `notes_ta2_1' `notes_ta2_2' `notes_ta2_3'}" _n
file write ta2 "\end{table}" _n
file close ta2

//%9.3f (r(mean))
//file write ta2 "DeathRate & Nearest-Neighbor Matching & `attnw_nt' & `attnw_nc' & %9.3f (`attnw_t') & %9.3f (`attnw_se') \\" _n
//file write ta2 "DeathRate & Kernel Matching           & `attk_nt'  & `attk_nc'  & %9.3f (`attk_t')  & %9.3f (`attk_se')  \\" _n
//file write ta2 "DeathRate & Radius Matching           & `attr_nt'  & `attr_nc'  & %9.3f (`attr_t')  & %9.3f (`attr_se')  \\" _n



* TABLE A3 

foreach var in ldeath deathrate d_death {
xi: areg `var' PC ls ROA_w iv capint sp  i.year i.sic2*year, absorb(province) cluster(code) 
eststo ta3_`var'_1
//outreg2 PC ls ROA_w iv capint sp  using TableA3.xls, append sortvar(PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Industry;Province",Sample, "Full") 
xi: areg `var' PC ls ROA_w iv capint sp log_emp i.year i.sic2*year if var_PC==1, absorb(province) cluster(code) 
eststo ta3_`var'_2
//outreg2 PC ls ROA_w iv capint sp  using TableA3.xls, append sortvar(PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Industry;Province",Sample, "Var(Connected)>0") 
xi: areg `var' PC ls ROA_w iv capint sp  i.year i.sic2*year if var_PC==1, absorb(code) cluster(code) 
eststo ta3_`var'_3
//outreg2 PC ls ROA_w iv capint sp  using TableA3.xls, append sortvar(PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Firm",Sample, "Var(Connected)>0") 
}

esttab ta3_ldeath_1 ta3_ldeath_2 ta3_ldeath_3   ta3_deathrate_1 ta3_deathrate_2 ta3_deathrate_3   ta3_d_death_1 ta3_d_death_2 ta3_d_death_3    ///
using ./tables/ta3.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps ///
nodepvars b(%9.3f) legend constant noabbrev style(tex)  ///
title(`"Appendix Table A3: The effect of political connections on worker deaths, industry time trends included"')   ///
nomtitles ///
label stats(N r2, fmt(%9.0g %9.3g)       ///
labels("Observations" "R-Squared")) se   ///
order(PC ls ROA_w iv capint sp _cons)    ///
keep(PC ls ROA_w capint sp _cons)     ///
nonotes ///
posthead(	" & \multicolumn{3}{c}{Columns 1 - 3: log(1 + death)} & \multicolumn{3}{c}{Columns 4 - 6: DeathRate} & \multicolumn{3}{c}{Columns 7 - 9: I(Deaths$ >$ 0)} \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"              & Year; Industry; & Year; Industry; & Year; Firm & Year; Industry; & Year; Industry; & Year; Firm  & Year; Industry; & Year; Industry; & Year; Firm  \\"  ///
		"Fixed Effects & Province        & Province        &            & Province        & Province        &             & Province        & Province        &             \\"  ///
		"Sample        & Full & `var_ctd' & `var_ctd' & Full & `var_ctd' & `var_ctd' & Full & `var_ctd' & `var_ctd' \\"  ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			"\caption{Notes: All variables are at the firm-year level.  All specifications include industry-specific time trends.  `deaths'; `death_rate'; `connected_1' `connected_2'; `cap_int'; `investment'; `state_ownership'. `nsnp'; `pollute'.  `var_connected'.  `std_err'.  \newline `significance'. }"  ///
			"\end{sidewaystable}")  ///
substitute(	\begin{table}[htbp]\centering \begin{sidewaystable}[htbp]\centering\footnotesize{ )




* NEW ANALYSIS ON VIOLATIONS, MAINLY POLLUTION
use data_post2007,replace
drop post effective_year

g effective_year=year(effectivedate_stata)
g post=financialyear>=effective_year


* TABLE 4
tab PC d_death,sum(viol)
tab PC d_death if var_PC==1,sum(viol)


//connected=0, deaths=0
sum viol if d_death == 0 & PC == 0 & var_PC == 1
local nc_nd = "`: di %9.3f r(mean)'"
//connected=0, deaths>0
sum viol if d_death > 0 & PC == 0 & var_PC == 1
local nc_d = "`: di %9.3f r(mean)'"

//connected=1, deaths=0
sum viol if d_death == 0 & PC == 1 & var_PC == 1
local c_nd = "`: di %9.3f r(mean)'"
//connected=1, deaths>0
sum viol if d_death > 0 & PC == 1 & var_PC == 1
local c_d = "`: di %9.3f r(mean)'"

//no death difference
local nd_diff = "`: di  %9.3f `nc_nd' - `c_nd' '"   //round(`nc_nd' - `c_nd', .001)
//death difference
local d_diff = "`: di  %9.3f `nc_d' - `c_d' '"   //round(`nc_d' - `c_d', .001)


//out to latex
file open t4 using "tables/t4.tex", write replace
file write t4 "\begin{table}[htbp]\centering\footnotesize{" _n
file write t4 "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" _n
file write t4 "\caption{Table 4: Crosstab of Connected and I(Deaths$>$0) for average safety violation rate (\emph{SafetyViol}) }" _n
file write t4 "\begin{tabular}{l*{2}{c}}" _n
file write t4 "\hline\hline" _n
file write t4 " & Deaths=0 & Deaths$>$0 \\" _n
file write t4 "\hline" _n
file write t4 "\emph{Connected=0} & `nc_nd' & `nc_d' \\" _n
file write t4 "\emph{Connected=1} & `c_nd' & `c_d' \\" _n
file write t4 "Difference & `nd_diff' & `d_diff' \\" _n
file write t4 "\hline\hline" _n
file write t4 "\end{tabular}}" _n
file write t4 "\caption{Notes: Sample includes 325 firms with variation in \emph{Connected} during 2008-2013; `deaths'; `i_deaths'; `connected_1' `connected_2'; `safety_viol'.}" _n
file write t4 "\end{table}" _n
file close t4


* eric 09/13/2014: 

* note that for this second sample, the fisher exact test yields a p-value of 0.11. maybe worth mentioning this. but also that the inclusion of covariates obviously makes it fall apart
* that's separate from the weird selection issues associated with being in the media

//eric 09/11/2014: comment this out
//fptest viol if d_death==0 & var_PC==1,by(PC)

* we can't really split the sample any more as we already have so many zeros

* this is partly what motivates us to look at pollution - it's something where we observe actual violations rather than
* just media reports of (major) violations. we don't have actual violations so implicit in this is that
* at a minimum PC=1 firms don't actually pollute *less*

* now, a focus on pollution

//label variable iv ""

* TABLE 5
* just the limited ever-connected sample
xi: reg pollute PC if var_PC==1 , cluster(code) 
eststo t5_1
//outreg2 PC ls ROA_w iv capint sp  using Table_5.xls, replace sortvar(PC post post_PC d_death ls ROA_w iv capint sp) addtext(Fixed Effects, "-",Sample,"Var(Connected)>0") 
xi: reg pollute PC ls ROA_w iv capint sp  if var_PC==1 , cluster(code) 
eststo t5_2
//outreg2 PC ls ROA_w iv capint sp  using Table_5.xls, append sortvar(PC post post_PC d_death ls ROA_w iv capint sp) addtext(Fixed Effects, "-",Sample,"Var(Connected)>0") 
xi: areg pollute PC ls ROA_w iv capint sp  i.year i.sic2 if var_PC==1 , absorb(province) cluster(code) 
eststo t5_3
//outreg2 PC ls ROA_w iv capint sp  using Table_5.xls, append sortvar(PC post post_PC d_death ls ROA_w iv capint sp) addtext(Fixed Effects, "Year;Industry;Province",Sample,"Var(Connected)>0") 

label variable ls "log(Sales)"
label variable PC "Connected"
label variable ROA_w "ROA"
label variable iv "Investment"
label variable capint "CapInt"
label variable sp "StateOwnership"

esttab t5_1 t5_2 t5_3 ///
using ./tables/t5.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps  ///
nodepvars b(%9.3f) legend constant noabbrev style(tex) ///
title(`"Table 5: The impact of political connections on environmental noncompliance"')   ///
nomtitles ///
label stats(N r2, fmt(%9.0g %9.3g)       ///
labels("Observations" "R-Squared")) se   ///
order(PC ls ROA_w iv capint sp _cons)    ///
keep(PC ls ROA_w iv capint sp _cons)     ///
nonotes ///
posthead(	" & \multicolumn{3}{c}{Columns 1 - 3: Pollute} \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"Fixed Effects & - & -                     & Year; Industry; Province \\"  ///
		"Sample        &   & `var_ctd' &                          \\"  ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			`"\caption{Notes: All variables are at the firm-year level.  `pollute'; `connected_1' `connected_2'; `cap_int'; `investment'; `state_ownership'.  `var_connected'.  `std_err'. \newline `significance'.}"'  ///
			"\end{table}")  ///
substitute(	\begin{table}[htbp]\centering \begin{table}[htbp]\centering\footnotesize{ )




* TABLE 6
* PROFITABILITY REGRESSIONS
xi: areg ROA_w PC ls iv capint sp  i.year i.sic2 , absorb(province) cluster(code) 
eststo t6_1
//outreg2 PC ls ROA_w iv capint sp  using Table_6.xls, replace sortvar(PC post post_PC d_death ls ROA_w iv capint sp) addtext(Fixed Effects, "Year;Industry;Province",Sample,"Full") 
xi: areg ROA_w PC ls iv capint sp  i.year i.sic2 if var_PC==1 , absorb(province) cluster(code) 
eststo t6_2
//outreg2 PC ls ROA_w iv capint sp  using Table_6.xls, append sortvar(PC post post_PC d_death ls ROA_w iv capint sp) addtext(Fixed Effects, "Year;Industry;Province",Sample,"Var(Connected)>0") 
tsset code year
g fwd_ROA_w=f.ROA_w
g fwd_PC=f.PC
g PC_d_death=PC*d_death
g PC_severetag=PC*severetag
xi: areg fwd_ROA_w PC ls iv capint sp d_death PC_d_death ROA_w i.year i.sic2 , absorb(province) cluster(code) 
eststo t6_3
//outreg2 PC ls iv capint sp ROA_w d_death PC_d_death using Table_6.xls, append sortvar(PC post post_PC deathrate ls iv capint sp deathrate PC_deathrate ROA_w ) addtext(Fixed Effects, "Year;Industry;Province",Sample,"Full")
xi: areg fwd_ROA_w PC ls iv capint sp d_death PC_d_death ROA_w i.year i.sic2 if var_PC==1 , absorb(province) cluster(code) 
eststo t6_4
//outreg2 PC ls iv capint sp ROA_w d_death PC_d_death using Table_6.xls, append sortvar(PC post post_PC deathrate ls iv capint sp deathrate PC_deathrate ROA_w ) addtext(Fixed Effects, "Year;Industry;Province",Sample,"Var(Connected)>0")

label variable PC "Connected"
label variable ls "log(Sales)"
label variable iv "Investment"
label variable capint "CapInt"
label variable PC_d_death "Connected * I(Deaths$ >$ 0)"
label variable d_death "I(Deaths$ > $ 0)"
label variable ROA_w "ROA"

esttab t6_1 t6_2 t6_3 t6_4 ///
using ./tables/t6.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps   ///
nodepvars b(%9.3f) legend constant noabbrev style(tex) ///
title(`"Table 6: Political connections, deaths and firm performance"')   ///
nomtitles ///
label stats(N r2, fmt(%9.0g %9.3g)       ///
labels("Observations" "R-Squared")) se   ///
order(PC ls iv capint sp d_death PC_d_death ROA_w _cons)    ///
keep(PC ls iv capint sp d_death PC_d_death ROA_w _cons)     ///
nonotes ///
posthead(	" & \multicolumn{2}{c}{Columns 1 - 2: ROA} & \multicolumn{2}{c}{Columns 3 - 4: ROA\_F1} \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"Fixed Effects & \multicolumn{4}{c}{Year; Industry; Province} \\"  ///
		"Sample        & Full & `var_ctd' & Full & `var_ctd' \\"  ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			"\caption{Notes: All variables are at the firm-year level.  `roa_f1'; `deaths'; `i_deaths'; `connected_1' `connected_2'; `cap_int'; `investment'; `state_ownership'.  `var_connected'. `std_err'.  \newline `significance'.}"  ///
			"\end{table}")  ///
substitute(	\begin{table}[htbp]\centering \begin{table}[htbp]\centering\footnotesize{ )




* TABLE 8
* (table 7 is above in event study)
xi: areg fwd_PC d_death PC sp  ls capint ROA_w iv i.year i.sic2, absorb(province) cluster(code)
eststo t8_1
//outreg2 d_death PC PC_d_death sp  ls capint ROA_w iv using Table_8.xls, replace sortvar(d_death PC  sp  ls capint ROA_w iv ) addtext(Fixed Effects, "Year;industry;province",Sample,"Full") 
xi: areg fwd_PC d_death PC sp  ls capint ROA_w iv i.year i.sic2 if var_PC==1, absorb(province) cluster(code)
eststo t8_2
//outreg2 d_death PC PC_d_death sp  ls capint ROA_w iv using Table_8.xls, append sortvar(d_death PC sp  ls capint ROA_w iv ) addtext(Fixed Effects, "Year;industry;province",Sample,"Var(Connected)>0") 
xi: areg fwd_PC d_death PC sp  ls capint ROA_w iv i.year i.sic2 if var_PC==1, absorb(code) cluster(code)
eststo t8_3
//outreg2 d_death PC PC_d_death sp  ls capint ROA_w iv using Table_8.xls, append sortvar(d_death PC sp  ls capint ROA_w iv ) addtext(Fixed Effects, "Firm",Sample,"Var(Connected)>0") 

esttab t8_1 t8_2 t8_3 ///
using ./tables/t8.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps ///
nodepvars b(%9.3f) legend constant noabbrev style(tex)  ///
title(`"Table 8: The effect of workplace deaths on political connections"')   ///
nomtitles ///
label stats(N r2, fmt(%9.0g %9.3g)       ///
labels("Observations" "R-Squared")) se   ///
order(d_death PC sp  ls capint ROA_w iv _cons) ///
keep(d_death PC sp  ls capint ROA_w iv _cons)  ///
nonotes ///
posthead(	" & \multicolumn{3}{c}{Columns 1 - 3: Connected\_F1} \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"Fixed Effects & Year; Industry; Province & Year; Industry; Province & Firm \\"  ///
		"Sample        & Full & `var_ctd' & `var_ctd' \\"  ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			`"\caption{Notes: All variables are at the firm-year level. `connected_1' `connected_2'; `connected_f1'; `deaths'; `i_deaths'; `cap_int'; `investment'; `state_ownership'. `var_connected'. `std_err'. \newline `significance'. }"'  ///
			"\end{table}")  ///
substitute(	\begin{table}[htbp]\centering \begin{table}[htbp]\centering\footnotesize{ )


* Graph/Xtab on shock, to start out
*/


* we start out by getting death residuals
use data_post2007,replace
drop post effective_year

g effective_year=year(effectivedate_stata)
g post=financialyear>=effective_year

* death rates lower in places where safety quotas in place
tab post,sum(deathrate)

* now, the 'within' sample
g dnsnp_sample=effective_year>2007 & effective_year<2012

* TABLE 9
tab post if dnsnp_sample==1,sum(deathrate)
tab post PC if dnsnp_sample==1,sum(deathrate)

//all firms, NSNP=0 and NSNP=1
sum deathrate if post == 0 & dnsnp_sample == 1
local all_0 = "`: di %9.3f r(mean)'"
sum deathrate if post == 1 & dnsnp_sample == 1
local all_1 = "`: di %9.3f r(mean)'"

//unconnected firms, NSNP=0 and NSNP=1
sum deathrate if post == 0 & dnsnp_sample == 1 & PC == 0
local unconnected_0 = "`: di %9.3f r(mean)'"
sum deathrate if post == 1 & dnsnp_sample == 1 & PC == 0
local unconnected_1 = "`: di %9.3f r(mean)'"

//connected firms, NSNP=0 and NSNP=1
sum deathrate if post == 0 & dnsnp_sample == 1 & PC == 1
local connected_0 = "`: di %9.3f r(mean)'"
sum deathrate if post == 1 & dnsnp_sample == 1 & PC == 1
//two underscores keep the variable separate from the description of connected
local connected__1 = "`: di %9.3f r(mean)'"

//unconnected difference
local unconnected_diff = "`: di  %9.3f `unconnected_0' - `unconnected_1' '"   //round(`nc_nd' - `c_nd', .001)
//connected difference
local connected_diff = "`: di  %9.3f `connected_0' - `connected__1' '"   //round(`nc_d' - `c_d', .001)

file open t9 using "tables/t9.tex", write replace
file write t9 "\begin{table}[htbp]\centering\footnotesize{" _n
file write t9 "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" _n
file write t9 "\caption{Table 9: Crosstab of Connected and NSNP for Deathrate }" _n
file write t9 "\begin{tabular}{l*{3}{c}}" _n
file write t9 "\hline\hline" _n
file write t9 " & All Firms & Unconnected & Connected \\" _n
file write t9 "\hline" _n
file write t9 "NSNP=0 & `all_0' & `unconnected_0'  & `connected_0' \\" _n
file write t9 "NSNP=1 & `all_1' & `unconnected_1'  & `connected__1' \\" _n
file write t9 "Difference &   & `unconnected_diff' & `connected_diff'\\" _n
file write t9 "\hline\hline" _n
file write t9 "\end{tabular}}" _n
file write t9 "\caption{Notes: Sample includes the 564 observations from firms headquartered in provinces that implemented an NSNP law during 2009-2012; `deaths'; `death_rate'; `connected_1' `connected_2'; `nsnp'.}" _n
file write t9 "\end{table}" _n
file close t9



* now, we merge in log gdp etc

sort provinceid year
merge provinceid year using province_gdp_stata12
drop if _m==2
///*
foreach v in gdppercapita population {
	g log_`v'=log(`v')
	g PC_log_`v'=PC*log_`v'
}


***province-level intervention effect: no safety, no promotion policy
gen PC_post=PC*post
gen ls_post=ls*post

foreach var in province sic1 year {
	egen PC_`var'=group(PC `var')
}

egen province_year_sic=group(province year sic2)
egen province_year=group(province year)

* TABLE 10
foreach var in deathrate {
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.year i.sic2, absorb(province) cluster(code) 
	eststo t10_1
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year;Industry; Province",Sample,"Full") 
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.year i.sic2 if var_PC==1 , absorb(province) cluster(code) 
	eststo t10_2
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year;Industry; Province",Sample,"Var(Connected)>0") 
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.year i.sic2 if var_PC==1, absorb(code) cluster(code) 
	eststo t10_3
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year; Firm",Sample,"Var(Connected)>0") 	
}

foreach var in ROA_w {
	xi: areg `var' PC post PC_post ls capint sp  iv i.year i.sic2, absorb(province) cluster(code) 
	eststo t10_4
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year;Industry; Province",Sample,"Full") 
	xi: areg `var' PC post PC_post ls capint sp  iv i.year i.sic2 if var_PC==1 , absorb(province) cluster(code) 
	eststo t10_5
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year;Industry; Province",Sample,"Var(Connected)>0") 
	xi: areg `var' PC post PC_post ls capint sp  iv i.year i.sic2 if var_PC==1, absorb(code) cluster(code) 
	eststo t10_6
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year; Firm",Sample,"Var(Connected)>0") 	
}

foreach var in pollute {
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.year i.sic2, absorb(province) cluster(code) 
	eststo t10_7
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year;Industry; Province",Sample,"Full") 
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.year i.sic2 if var_PC==1 , absorb(province) cluster(code) 
	eststo t10_8
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year;Industry; Province",Sample,"Var(Connected)>0") 
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.year i.sic2 if var_PC==1, absorb(code) cluster(code) 
	eststo t10_9
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_10.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv) addtext(Fixed Effects, "Year; Firm",Sample,"Var(Connected)>0") 	
}

label variable PC "Connected"
label variable post "NSNP"
label variable PC_post "Connected * NSNP"
label variable ls "log(Sales)"
label variable capint "CapInt"
label variable sp "StateOwnership"
label variable ROA_w "ROA"
label variable iv "Investment"



esttab t10_1 t10_2 t10_3 t10_4 t10_5 t10_6 t10_7 t10_8 t10_9 ///
using ./tables/t10.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps  ///
nodepvars b(%9.3f) legend constant noabbrev style(tex)  ///
title(`"Table 10: The differential impacts of \enquote{No Safety, No Promotion} on firm-level outcomes"')   ///
nomtitles ///
label stats(N r2, fmt(%9.0g %9.3g)  ///
labels("Observations" "R-Squared")) se  ///
order(PC post PC_post ls capint sp  ROA_w iv _cons) ///
keep(PC post PC_post ls capint sp  ROA_w iv _cons)  ///
nonotes ///
posthead(	" & \multicolumn{3}{c}{Columns 1 - 3: DeathRate} & \multicolumn{3}{c}{Columns 4 - 6: ROA} & \multicolumn{3}{c}{Columns 7 - 9: Pollute}  \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"              & Year; Industry; & Year; Industry; & Year; Firm & Year; Industry; & Year; Industry; & Year; Firm & Year; Industry; & Year; Industry; & Year; Firm \\"  ///
		"Fixed Effects & Province & Province & Firm                     & Province & Province & Firm                      & Province & Province & Firm \\"  ///
		"Sample        & Full & `var_ctd' & `var_ctd' & Full & `var_ctd' & `var_ctd' & Full & `var_ctd' & `var_ctd' \\"  ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			`"\caption{Notes: All variables are at the firm-year level.  `deaths'; `death_rate'; `connected_1' `connected_2'; `cap_int'; `investment'; `state_ownership'; `nsnp'; `pollute'; `var_connected'.  `std_err'. \newline `significance'.}"'  ///
			"\end{sidewaystable}")  ///
substitute(	\begin{table}[htbp]\centering \begin{sidewaystable}[htbp]\centering\footnotesize{ )


label variable PC "Connected"
label variable post "NSNP"
label variable PC_post "Connected * NSNP"
label variable ls "log(Sales)"
label variable capint "CapInt"
label variable sp "StateOwnership"
label variable ROA_w "ROA"
label variable iv "Investment"
label variable ls_post "log(Sales) * NSNP"
label variable PC_log_gdppercapita "Connected * log(GDP per Capita)"

* appendix table A4
foreach var in deathrate {
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.year if var_PC==1 & dnsnp_sample==1, absorb(province) cluster(code) 
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_a4.xls, replace sortvar(PC post PC_post ls capint sp  ROA_w iv ls_post PC_log_gdppercapita) addtext(Fixed Effects, "Year; Industry; Province",Sample,"Var(Connected)>0;Var(NSNP)>0",Province Time Trends, "No") 
	eststo ta4_1
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.province*year i.year if var_PC==1, absorb(sic2) cluster(code) 
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_a4.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv ls_post PC_log_gdppercapita) addtext(Fixed Effects, "Year; Province; Industry",Sample,"Var(Connected)>0",Province Time Trends, "Yes") 
	eststo ta4_2
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv i.year i.sic2 if var_PC==1 , absorb(province_year) cluster(code) 
	//outreg2 PC post PC_post ls capint sp  ROA_w iv using Table_a4.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv ls_post PC_log_gdppercapita) addtext(Fixed Effects, "Province X Year;Industry",Sample,"Var(Connected)>0",Province Time Trends, "No") 
	eststo ta4_3
		
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv ls_post i.year i.sic2 if var_PC==1, absorb(province) cluster(code) 
	
	//outreg2 PC post PC_post ls capint sp  ROA_w iv ls_post using Table_a4.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv ls_post PC_log_gdppercapita) addtext(Fixed Effects, "Year; Industry; Province",Sample,"Var(Connected)>0",Province Time Trends, "No")  
	eststo ta4_4
	xi: areg `var' PC post PC_post ls capint sp  ROA_w iv PC_log_gdppercapita i.year i.sic2 if var_PC==1 , absorb(province) cluster(code) 
	//outreg2 PC post PC_post ls capint sp  ROA_w iv PC_log_gdppercapita using Table_a4.xls, append sortvar(PC post PC_post ls capint sp  ROA_w iv ls_post PC_log_gdppercapita) addtext(Fixed Effects, "Year; Industry; Province",Sample,"Var(Connected)>0",Province Time Trends, "No")  	
	eststo ta4_5
}


esttab ta4_1 ta4_2 ta4_3 ta4_4 ta4_5 ///
using ./tables/ta4.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps  ///
nodepvars b(%9.3f) legend constant noabbrev style(tex) ///
title(`"Appendix Table A4: The differential impacts of \enquote{No Safety, No Promotion}: Robustness"')   ///
nomtitles ///
label stats(N r2, fmt(%9.0g %9.3g)  ///
labels("Observations" "R-Squared")) se  ///
order(PC post PC_post ls capint sp  ROA_w iv  ls_post PC_log_gdppercapita _cons)  ///
keep(PC post PC_post ls capint sp  ROA_w iv  ls_post PC_log_gdppercapita _cons)   ///
nonotes ///
posthead(	" & \multicolumn{5}{c}{Columns 1 - 5: DeathRate} \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"Fixed Effects & Year; Industry;  & Year; Industry; & Province X Year; & Year; Indsutry; & Year; Industry; \\"  ///
		"              &  Province        & Province        & Industry         & Province        &  Province       \\"  ///
		"Sample        & `var_ctd'; Var(NSNP)$>$0 & `var_ctd'  & `var_ctd'     & `var_ctd'       & `var_ctd'       \\"  ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			`"\caption{Notes: All variables are at the firm-year level.  `deaths'; `death_rate'; `connected_1' `connected_2'; `cap_int'  `std_err'.  \newline `significance'.}"'  ///
			"\end{table}")  ///
substitute(	\begin{table}[htbp]\centering \begin{table}[htbp]\centering\footnotesize{ )



***now bootstrapping the standard error in the above regressions.
tsset, clear
set seed 10
//bootstrap, reps(100): areg ldeath PC post PC_post ls capint sp  ROA_w iv   _Iyear_*   _Isic2_*, absorb(province) cluster(province)
//outreg2 using "tableX1", replace  bdec(3)  adjr2  excel
//bootstrap, reps(100): areg ldeath PC post PC_post ls capint sp  ROA_w iv   _Iyear_*   _Isic2_*, absorb(code) cluster(province)
//outreg2 using "tableX1", append  bdec(3)  adjr2  excel
//bootstrap, reps(100): areg ldeath PC post PC_post ls capint sp  ROA_w iv   _Iyear_*   _Isic2_*, absorb(PC_province) cluster(province)
//outreg2 using "tableX1", append  bdec(3)  adjr2  excel




* Now, the role of under-reporting. A few things make us think this is relatively unlikely

* effect is just as large - somewhat larger - in non-mining industries
* these results won't appear in the paper or an appendix, just reported in the text
g mining_PC=((sic1=="B0"))*PC
g construction_PC=(sic1=="E0")*PC
g safety_PC=mining_PC+construction_PC
g safety=(sic1=="B0")|(sic1=="E0")

/*
xi: areg ldeath PC ls ROA_w iv capint sp  mining_PC i.year i.sic2 , absorb(year) cluster(code) 
outreg2 PC ls ROA_w iv capint sp  using Table_Appendix1.xls, replace sortvar(PC mining_PC ls ROA capint sp  iv) addtext(Fixed Effects, "DROP THIS COLUMN") 
foreach var in deathrate {
	foreach sic in mining {
		xi: areg `var' PC ls ROA_w iv capint sp  `sic'_PC i.year i.sic2 , absorb(province) cluster(code) 
		outreg2 PC `sic'_PC ls ROA_w iv capint sp  using Table_Appendix_mining.xls, append sortvar(PC `sic'_PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Industry;Province",Sample, "Full") 
		xi: areg `var' PC ls ROA_w iv capint sp  `sic'_PC i.year i.sic2 if var_PC==1 , absorb(province) cluster(code) 
		outreg2 PC `sic'_PC ls ROA_w iv capint sp  using Table_Appendix_mining.xls, append sortvar(PC `sic'_PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Industry;Province",Sample, "Var(Connected)>0") 
		xi: areg `var' PC ls ROA_w iv capint sp  `sic'_PC i.year if var_PC==1, absorb(code) cluster(code) 
		outreg2 PC `sic'_PC ls ROA_w iv capint sp  using Table_Appendix_mining.xls, append sortvar(PC `sic'_PC ls ROA capint sp  iv) addtext(Fixed Effects, "Year;Firm",Sample, "Var(Connected)>0") 
	}
}
*/

label variable PC "Connected" 
label variable ls "log(Sales)"
label variable ROA_w "ROA"
label variable iv "Investment"
label variable capint "CapInt"
label variable sp "State Ownership"

* effect is just as big for 'severe' accidents (deaths>=3)
xi: areg severetag PC ls ROA_w iv capint sp  i.year i.sic2 , absorb(province) cluster(code) 
eststo t11_1
//outreg2 PC ls ROA_w iv capint sp  using Table_11.xls, replace addtext(Fixed Effects, "Year;Industry;Province",Sample, "Full") 
xi: areg severetag PC ls ROA_w iv capint sp  i.year i.sic2 if var_PC==1, absorb(province) cluster(code) 
eststo t11_2
//outreg2 PC ls ROA_w iv capint sp  using Table_11.xls, append addtext(Fixed Effects, "Year;Industry;Province",Sample, "Var(Connected)>0") 
xi: areg severetag PC ls ROA_w iv capint sp  i.year if var_PC==1, absorb(code) cluster(code) 
eststo t11_3
//outreg2 PC ls ROA_w iv capint sp  using Table_11.xls, append addtext(Fixed Effects, "Year;Firm",Sample, "Var(Connected)>0") 

esttab t11_1 t11_2 t11_3 ///
using ./tables/t11.tex, replace   ///
star(* 0.10 ** 0.05 *** 0.01) /*plain*/ nogaps  ///
nodepvars b(%9.3f) legend constant noabbrev style(tex) ///
title(`"Table 11: The impact of connections on severe accident rates: A test of under-reporting"')   ///
nomtitles ///
label stats(N r2, fmt(%9.0g %9.3g)       ///
labels("Observations" "R-Squared")) se   ///
order(PC ls ROA_w iv capint sp _cons)    ///
keep(PC ls ROA_w iv capint sp _cons)     ///
nonotes ///
posthead(	" & \multicolumn{3}{c}{Columns 1 - 3: Severe}  \\"   ///
			"\hline")  ///
prefoot("\hline" ///
		"Fixed Effects & Year; Industry; Province & Year; Industry; Province & Year; Firm \\"  ///
		"Sample & Full & `var_ctd' & `var_ctd' \\"  ///
		"\hline")  ///
postfoot(	"\hline\hline" ///
			"\end{tabular}}"  ///
			`"\caption{Notes: All variables are at the firm-year level.  `severe'; `connected_1' `connected_2'; `cap_int'; `investment'; `state_ownership'. `var_connected'. `std_err'. \newline `significance'.}"'  ///
			"\end{table}")  ///
substitute(	\begin{table}[htbp]\centering \begin{table}[htbp]\centering\footnotesize{ )


gen pc_post = PC * post
label variable pc_post "Connected * NSNP"


// import Table A1 
import excel using "table_A1.xlsx", sheet("Sheet1") clear firstrow

//drop notes
drop if _n == 32
rename *, lower
compress

//format dates
replace effectivedate = substr(effectivedate, 1, 2) + "-" + substr(effectivedate, 3, 3) + "-" + substr(effectivedate, 6, 4) if effectivedate != "No safety quota"
replace passagedate = substr(passagedate, 1, 2) + "-" + substr(passagedate, 3, 3) + "-" + substr(passagedate, 6, 4) if passagedate != "No safety quota"

//upper case months
replace effectivedate = substr(effectivedate, 1, 3) + strupper(substr(effectivedate, 4, 1)) + substr(effectivedate, 5, .) if  effectivedate != "No safety quota"
replace passagedate = substr(passagedate, 1, 3) + strupper(substr(passagedate, 4, 1)) + substr(passagedate, 5, .) if passagedate != "No safety quota"

local notes_1 = "Since 2004, China has followed a \enquote{safety production quota} system, whereby the central government assigns a \enquote{death quota} to each province, and the provincial government allocates the quota among municipalities."
local notes_2 = "In response, provinces began adopting \enquote{no safety, no promotion} policies that made promotion of safety regulators and other local government officials contingent on meeting "
local notes_3 = "the safety production target set for their region by the provincial government."
local notes_4 = "Guodoing was the first province to adopt this policy in 2005, while others followed suit only in recent years." 
local notes_5 = "Deaths is the number of worker deaths among firms in our sample."
local notes_6 = "Firm-year obs is the number of observations that firms based in each province contribute to our sample. "
local notes_7 = "Population is province population in 2005. GDP P.C. is income per capita in 2005."
local notes_8 = "Both population and income figures are obtained from CSMAR Regioual Economy Database."



listtex * using tables/ta1.tex, replace rstyle(tabular) ///
		head(	"\begin{table}[htbp]\centering\footnotesize{"  ///
				"\caption{Table A1: Instatement of \enquote{no safety, no promotion} laws by province}"  ///
				"\begin{tabular}{l c c c c c c}"  ///
				"\hline\hline"  ///
				"Province & Effective Date & Passage Date & Deaths & Firm-year obs & Population in 2005 & GDP per capita in 2005\\"  ///
				"         &                &              &        &               & (unit: 10,000)     & (unit: 1 RMB)         \\"  ///
				"\hline")  ///
		foot(	"\hline"  ///
				"\end{tabular}}"  ///
				"\caption{Notes: `notes_1' `notes_2' `notes_3' `notes_4' `notes_5' `notes_6' `notes_7' `notes_8'}"  ///
				"\end{table}")


cd ../
*/

